
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.10'
version = '1.2.10'
full_version = '1.2.10'
git_revision = '41451bc809df38cc98e01e26e598060c5fee5cff'
release = True

if not release:
    version = full_version
    short_version += ".dev"
